# mkreadme

[![PyPI version](https://badge.fury.io/py/mkreadme.svg)](https://badge.fury.io/py/mkreadme)
[![Python version](https://img.shields.io/badge/python-≥3.8-blue.svg)](https://pypi.org/project/kedro/)
[![Release Pipeline](https://github.com/AnH0ang/mkreadme/actions/workflows/release.yml/badge.svg)](https://github.com/AnH0ang/mkreadme/actions/workflows/release.yml)
[![Code Quality](https://github.com/AnH0ang/mkreadme/actions/workflows/code_quality.yml/badge.svg)](https://github.com/AnH0ang/mkreadme/actions/workflows/code_quality.yml)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://github.com/AnH0ang/nbenumerate/blob/master/LICENCE)
![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)

## 📝 Description

`mkreadme` is a cli tool for interactive creation of a `README.md` file. It was inspired by [readme.so](https://readme.so/). You can choose from different `README` sections, which are then merged into a complete document.

## ⚙️ Installation

Install `mkreadme` with `pip`

```bash
  pip install mkreadme
```

## 💡 Usage Examples

To interactively create a README file with `mkreadme`, run

```console
mkreadme --filename README.md
```

## 🖼️ Screenshots

![App Screenshot](static/Screenshot.png)
